constants library

Constants for Google Cloud Platform integration.

Constants

cloudTraceContextHeader → const String
Standard HTTP header used by Cloud Trace.
configurationEnvironmentVariable → const String
The name of the Cloud Run configuration being run.
credentialsPathEnvironmentVariable → const String
Standard environment variable for specifying the path to a service account JSON file.
defaultListenPort → const int
The default port a service should listen on if portEnvironmentVariable is not set.
metadataFlavorHeaders → const Map<String, String>
Standard HTTP request headers expected by the Metadata Server.
portEnvironmentVariable → const String
The standard environment variable for specifying the port a service should listen on.
projectIdEnvironmentVariable → const String
The standard environment variable for specifying the Google Cloud project ID.
projectIdEnvironmentVariableOptions → const Set<String>
A set of standard environment variables that are likely to represent the current Google Cloud project ID.
revisionEnvironmentVariable → const String
The name of the Cloud Run revision being run.
serviceEnvironmentVariable → const String
The name of the Cloud Run service being run.