projectIdEnvironmentVariableOptions top-level constant

Set<String> const projectIdEnvironmentVariableOptions

A set of standard environment variables that are likely to represent the current Google Cloud project ID.

For context, see:

Note: these are ordered starting from the most current/canonical to least. (At least as could be determined at the time of writing.)

Implementation

const projectIdEnvironmentVariableOptions = {
  projectIdEnvironmentVariable,
  'GCP_PROJECT',
  'GCLOUD_PROJECT',
  'CLOUDSDK_CORE_PROJECT',
};