MetadataServerException class final

Exception thrown when accessing the GCE metadata server fails.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
innerException Object?
The inner exception that caused this failure, if any.
final
innerStackTrace StackTrace?
The stack trace of the inner exception, if any.
final
message String
The message explaining the error.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited