gceMetadataUrl function

Uri gceMetadataUrl(
  1. String path
)

Returns a Uri for the given path on the GCE metadata server.

path is the relative path to the metadata value.

Implementation

Uri gceMetadataUrl(String path) =>
    Uri.parse('http://$gceMetadataHost/computeMetadata/v1/$path');