RequestLogger class abstract final

Allows logging at a specified severity.

Compatible with the log severities supported by Google Cloud.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

alert(Object message) → void
Logs message at LogSeverity.alert severity.
critical(Object message) → void
Logs message at LogSeverity.critical severity.
debug(Object message) → void
Logs message at LogSeverity.debug severity.
emergency(Object message) → void
Logs message at LogSeverity.emergency severity.
error(Object message) → void
Logs message at LogSeverity.error severity.
info(Object message) → void
Logs message at LogSeverity.info severity.
log(Object message, LogSeverity severity) → void
Logs message at the given severity.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notice(Object message) → void
Logs message at LogSeverity.notice severity.
toString() String
A string representation of this object.
inherited
warning(Object message) → void
Logs message at LogSeverity.warning severity.

Operators

operator ==(Object other) bool
The equality operator.
inherited