currentLogger top-level property

RequestLogger get currentLogger

Returns the current RequestLogger.

If called within a context configured with a RequestLogger, the returned RequestLogger will be used.

Otherwise, the returned RequestLogger will simply print log entries, with entries having a LogSeverity different than LogSeverity.defaultSeverity being prefixed as such.

Implementation

RequestLogger get currentLogger =>
    Zone.current[_loggerKey] as RequestLogger? ?? const _DefaultLogger();